@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: app.c,v 1.1.1.1 2003/12/04 00:10:12 dom Exp $
- *   $Date: 2003/12/04 00:10:12 $
+ *   $Id: app.c,v 1.3 2003/12/13 14:11:09 dom Exp $
+ *   $Date: 2003/12/13 14:11:09 $
  *
  *
  *   Implements the skeleton application
@@ -12,7 +12,16 @@
  *   This abstracts part of the old interface from gui.c into a separate file for libraryification
  */
 
-#include "menuapp.h"
+
+
+#include "app.h"
+#include "vdrurl.h"
+
+
+static void      *new_app(dongle_t *dongle, render_t *render);
+static void       delete_app(void *iapp);
+static void       app_keypress(void *iapp, int code);
+static void       app_ack(void *iapp, int ackcode, uint8_t *buf, int buflen);
 
 
 typedef struct {
@@ -29,7 +38,6 @@ typedef struct {
 struct _app {
     dongle_t     *dongle;
     render_t     *render;
-    gui_t        *gui;
     keyhandle_t   menus;
     keyhandle_t   media;
     ackhandle_t   menus_ack;
@@ -38,25 +46,31 @@ struct _app {
 };
 
 
-void app_config()
+
+void app_init(mvpinit_t *init)
 {
-    menuapp_config();
+
+    /* Register our handlers */
+    init->new_app = new_app;
+    init->delete_app = delete_app;
+    init->app_keypress = app_keypress;
+    init->app_handle_ack = app_ack;
+//    init->debug_level = 10;
+    init->logfile = fopen("/dev/null","w");
+ 
+
+    urlhandler_add("vdr://",cMediamvpVdrURL::Open,cMediamvpVdrURL::Close,cMediamvpVdrURL::Seek);
+
 }
 
 
-void app_init()
-{
-    menuapp_init();
-}
 
-
-void *new_app(dongle_t *dongle, render_t *render, gui_t *gui)
+static void *new_app(dongle_t *dongle, render_t *render)
 {
-    app_t  *app = malloc(sizeof(*app));
+    app_t  *app = (app_t *) malloc(sizeof(*app));
 
     app->dongle = dongle;
     app->render = render;
-    app->gui    = gui;
     app->media.key_func = NULL;
     app->menus.key_func = NULL;
     app->media_ack.ack_func = NULL;
@@ -68,9 +82,9 @@ void *new_app(dongle_t *dongle, render_t *render, gui_t *gui)
 }
 
 
-void delete_app(void *iapp)
+static void delete_app(void *iapp)
 {
-    app_t      *app = iapp;
+    app_t      *app = (app_t *) iapp;
 
     delete_menuapp(app->menuapp);
 
@@ -81,31 +95,11 @@ void delete_app(void *iapp)
 
 
 
-/** \brief Register key handling functions
- *
- *  \param app Handle the the app channel
- *  \param types REGISTER_MENU or REGISTER_MEDIA
- *  \param key_func Function to call back with key code
- *  \param param Generic pointer to pass back to the callback function
- *
- *  We have two sets of functions for handling keys - one whilst in the
- *  menu, and a second for playing media
- */
-void app_register_keys(app_t *app,int type, 
-                       int (*key_func)(void *param,int keycode), void *param)
-{
-    if ( type == REGISTER_MENU ) {
-        app->menus.key_func = key_func;
-        app->menus.param = param;
-    } else {
-        app->media.key_func = key_func;
-        app->media.param = param;
-    }
-}
 
-void app_keypress(void *iapp, int code)
+
+static void app_keypress(void *iapp, int code)
 {
-    app_t   *app = iapp;
+    app_t   *app = (app_t *) iapp;
 
     if ( app->media.key_func ) {
         /* Now pass the key onto the menu stuff if necessary */
@@ -119,9 +113,9 @@ void app_keypress(void *iapp, int code)
     }
 }
 
-void app_ack(void *iapp, int ackcode, uint8_t *buf, int buflen)
+static void app_ack(void *iapp, int ackcode, uint8_t *buf, int buflen)
 {
-    app_t   *app = iapp;
+    app_t   *app = (app_t *) iapp;
 
     if ( app->media_ack.ack_func ) {
         /* Now pass the key onto the menu stuff if necessary */
@@ -133,11 +127,32 @@ void app_ack(void *iapp, int ackcode, uint8_t *buf, int buflen)
     } else if ( app->menus_ack.ack_func ) {
         (app->menus_ack.ack_func)(buf[1],app->menus_ack.param,buf,buflen);
     } else {
-        printf("Can't deal with MEDIA_ACK type %d\n",buf[1]);
+//        printf("Can't deal with MEDIA_ACK type %d\n",buf[1]);
     }
 }
 
-
+/** \brief Register key handling functions
+ *
+ *  \param app Handle the the app channel
+ *  \param types REGISTER_MENU or REGISTER_MEDIA
+ *  \param key_func Function to call back with key code
+ *  \param param Generic pointer to pass back to the callback function
+ *
+ *  We have two sets of functions for handling keys - one whilst in the
+ *  menu, and a second for playing media
+ */
+void app_register_keys(void *iapp,int type, 
+                       int (*key_func)(void *param,int keycode), void *param)
+{
+    app_t *app = (app_t *)iapp;
+    if ( type == REGISTER_MENU ) {
+        app->menus.key_func = key_func;
+        app->menus.param = param;
+    } else {
+        app->media.key_func = key_func;
+        app->media.param = param;
+    }
+}
 
 
 /** \brief Register ack handling functions
@@ -150,11 +165,12 @@ void app_ack(void *iapp, int ackcode, uint8_t *buf, int buflen)
  *  We have two sets of functions for handling acks - one whilst in the
  *  menu, and a second for playing media
  */
-void app_register_ack(app_t *app, int type,
+void app_register_ack(void *iapp, int type,
                       int    (*ack_func)(int acktype, void *param, unsigned char
  *buf, int len),
                       void  *param)
 {
+    app_t *app = (app_t *)iapp;
     if ( type == REGISTER_MENU ) {
         app->menus_ack.ack_func = ack_func;
         app->menus_ack.param = param;
@@ -168,4 +184,3 @@ void app_register_ack(app_t *app, int type,
 
 
 
-
