@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: dongle.c,v 1.5 2003/12/04 14:08:43 dom Exp $
- *   $Date: 2003/12/04 14:08:43 $
+ *   $Id: dongle.c,v 1.6 2003/12/13 13:44:35 dom Exp $
+ *   $Date: 2003/12/13 13:44:35 $
  *
  *
  *   Dongle registration - maintains a list of dongles with their subcomponents 
@@ -34,7 +34,7 @@ dongle_t *dongle_return(char *address)
         }
     }
 
-    dprintf(DEBUG,"Registering new dongle at IP %s\n",address);
+    Dprintf(DEBUG,"Registering new dongle at IP %s\n",address);
 
     if ( first != -1 ) {
         dongle=&dongles[first];
@@ -63,7 +63,7 @@ dongle_t *dongle_return(char *address)
 void dongle_close(dongle_t *dongle)
 {
 
-    dprintf(DEBUG,"Closing dongle at address %s\n",dongle->address);
+    Dprintf(DEBUG,"Closing dongle at address %s\n",dongle->address);
 
     if ( dongle->gui ) {
         delete_gui(dongle->gui);
