@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: gui.c,v 1.9 2003/12/04 21:08:01 dom Exp $
- *   $Date: 2003/12/04 21:08:01 $
+ *   $Id: gui.c,v 1.11 2003/12/13 13:44:35 dom Exp $
+ *   $Date: 2003/12/13 13:44:35 $
  *
  *
  *   Handles the GUI...
@@ -58,7 +58,7 @@ int gui_init()
 
     event_add(&listen_event,NULL);
 
-    dprintf(DEBUG,"Listening on port %d for GUI connection\n",initparams.gui_port);
+    Dprintf(DEBUG,"Listening on port %d for GUI connection\n",initparams.gui_port);
 
     return 0;
 }
@@ -79,6 +79,7 @@ static gui_t *new_gui(dongle_t *dongle)
     gui->dongle = dongle;
     gui->state  = VNC_VERSION;
     gui->inbufstart = 0;
+    gui->send_update = TRUE;
     gui->render = new_render(initparams.gui_width,initparams.gui_depth);
     if ( initparams.new_app ) {
         gui->app    = initparams.new_app(dongle,gui->render); 
@@ -118,7 +119,7 @@ static void gui_accept(int fd, short event, void *arg)
     if ( ( cfd = tcp_accept(fd,&hostname) ) == -1 ) {
         return;
     }
-    dprintf(DEBUG,"Accepted GUI connection from host %s\n",hostname);
+    Dprintf(DEBUG,"Accepted GUI connection from host %s\n",hostname);
     dongle = dongle_return(hostname);
 
     if ( dongle->gui ) {
@@ -240,7 +241,7 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
             greenshift = *ptr++;
             blueshift = *ptr++;
 
-            dprintf(DEBUG,"Received SetPixelFormat bpp = %d depth = %d endian = %d truecolour = %d redmax = %d greenmax = %d bluemax = %d redshift = %d greenshift = %d blueshift = %d\n",
+            Dprintf(DEBUG,"Received SetPixelFormat bpp = %d depth = %d endian = %d truecolour = %d redmax = %d greenmax = %d bluemax = %d redshift = %d greenshift = %d blueshift = %d\n",
                    bpp,depth,endian,truecolour,
                    redmax,greenmax,bluemax,
                    redshift,greenshift,blueshift);
@@ -257,11 +258,11 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
             int       i;
             
             BUF_TO_INT16(num,ptr);
-            dprintf(DEBUG,"Client supports %d encodings: ",num);
+            Dprintf(DEBUG,"Client supports %d encodings: ",num);
             if ( len >= 4 + ( num * 4 ) ) {
                 for ( i = 0 ; i < num; i++ ) {
                     BUF_TO_INT32(type,ptr);
-                    dprintf(DEBUG,"type %d%s",type,i < num - 1 ? ", " : "\n");
+                    Dprintf(DEBUG,"type %d%s",type,i < num - 1 ? ", " : "\n");
                 }
                 diff = 4 + ( num * 4);
             } else {
@@ -281,7 +282,7 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
             BUF_TO_INT16(width,ptr);
             BUF_TO_INT16(depth,ptr);
 
-            dprintf(DEBUG,"Received %supdate request for (%d,%d) -> (%d,%d)\n",
+            Dprintf(DEBUG,"Received %supdate request for (%d,%d) -> (%d,%d)\n",
                     buf[1] ? "incremental " :"",
                    x,y,
                    x+width,y+depth);
@@ -301,7 +302,7 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
 
 
             if ( code != keyNone ) {
-                dprintf(DEBUG,"Received IR key %s\n",key_string(key));
+                Dprintf(DEBUG,"Received IR key %s\n",key_string(key));
 
                 /* If power key was pressed, shut everything down.. */
                 if ( code == keyPower ) {
@@ -331,7 +332,7 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
 
             BUF_TO_INT32(tlen,ptr);
 
-            dprintf(DEBUG,"Received client cuttext of length %d\n",tlen);
+            Dprintf(DEBUG,"Received client cuttext of length %d\n",tlen);
 
             if ( len >= 8 + tlen ) {
                 diff = 8 + tlen;
@@ -357,7 +358,7 @@ static int rfb_running(gui_t *gui, unsigned char *buf, int len)
                         }
                         gui->dongle->flickermode = buf[13];
                         gui->dongle->aspectratio = buf[14];
-                        dprintf(DEBUG,"TVmode %d output = %d flicker = %d aspect = %d\n",
+                        Dprintf(DEBUG,"TVmode %d output = %d flicker = %d aspect = %d\n",
                                gui->dongle->tvmode,
                                gui->dongle->videooutput,
                                gui->dongle->flickermode,
@@ -466,7 +467,7 @@ static void rfb_send_screen(gui_t *gui)
     if ( surface == NULL ) {
         return;
     }
-    dprintf(DEBUG,"Sending update\n");
+    Dprintf(DEBUG,"Sending update\n");
     gui->send_update = FALSE;
     yuvsize = render_get_yuvsize(gui->render);
     comp = calloc(yuvsize,1);  
