@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: misc.c,v 1.4 2003/12/04 12:52:10 dom Exp $
- *   $Date: 2003/12/04 12:52:10 $
+ *   $Id: misc.c,v 1.5 2003/12/13 13:44:35 dom Exp $
+ *   $Date: 2003/12/13 13:44:35 $
  *
  *
  *   Miscellaenous routines
@@ -27,11 +27,12 @@ void dump_hex(int level, unsigned char *buf, int len)
             }
         }
         fprintf(initparams.logfile,"\n");
+        fflush(initparams.logfile);
     }
 }
 
 
-void dprintf(int level, char *fmt, ...)
+void Dprintf(int level, char *fmt, ...)
 {
    va_list             ap;
 
@@ -39,6 +40,7 @@ void dprintf(int level, char *fmt, ...)
 
    if ( initparams.debug_level <= level ) {
        vfprintf(initparams.logfile,fmt,ap);
+       fflush(initparams.logfile);
    }
 
    va_end(ap);
