@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: mvp.c,v 1.6 2003/12/04 21:08:02 dom Exp $
- *   $Date: 2003/12/04 21:08:02 $
+ *   $Id: mvp.c,v 1.7 2003/12/13 13:44:35 dom Exp $
+ *   $Date: 2003/12/13 13:44:35 $
  *
  *
  *   More wrapping up of the C code, this effectively a version of
@@ -23,18 +23,16 @@ int mediamvp_server_init(mvpinit_t *init)
 
     initparams = *init;
 
-
     if ( initparams.logfile == NULL ) {
         initparams.logfile = stderr;
     }
-    dprintf(INFO,"MediaMVP server %s starting\n",SERVER_VERSION);
+    Dprintf(INFO,"MediaMVP server %s starting\n",SERVER_VERSION);
 
     if ( initparams.main_interfaceip == -1 ) {
          char hostbuf[1024];
          if ( gethostname(hostbuf,sizeof(hostbuf)-1) == -1 ) {
                  return -1;
          }
-         printf("Hostbuf is %s\n",hostbuf);
          if ( ( initparams.main_interfaceip = host_resolve(hostbuf) ) == - 1 ) {
             return -1;
          }
