@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: render.c,v 1.3 2003/12/04 12:12:40 dom Exp $
- *   $Date: 2003/12/04 12:12:40 $
+ *   $Id: render.c,v 1.4 2003/12/10 21:02:24 dom Exp $
+ *   $Date: 2003/12/10 21:02:24 $
  *
  *
  *   Handle rendering onto the RGB buffer stuff we've got
@@ -67,6 +67,7 @@ render_t *new_render(int width, int depth)
         render->layers[i] = calloc(width * depth,1);
     }
 
+
     /* Set up some handy functions.. */
     return render;
 }
@@ -204,9 +205,17 @@ void render_print(render_t *render, int x, int y, int maxwidth,char *text)
     int   nbsp[FONT_HEIGHT+2] = { 1, FONT_HEIGHT, 0 };
     int  *letter;
     int   width;
+    int   tabwidth = ( (maxwidth - x )  ) / 6;
 
     while ( *text ) {
         switch ( *text ) {
+        case '\t':        /* Do some nasty stuff to calculate tab stops,
+                           only really works for a full display */
+            while ( x + 1 < ( ( x / tabwidth ) + 1 ) * tabwidth && x < maxwidth ) {
+                printchar(render,x,y,nbsp);
+                x++;
+            }
+            break;                   
         case '\n':
             width = 1;          
             while ( x + width < maxwidth ) {
