@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: stream.c,v 1.5 2003/12/04 21:08:02 dom Exp $
- *   $Date: 2003/12/04 21:08:02 $
+ *   $Id: stream.c,v 1.11 2003/12/15 22:44:14 dom Exp $
+ *   $Date: 2003/12/15 22:44:14 $
  *
  *
  *   Handles the media stream socket..all a bit of mess at the moment..
@@ -23,6 +23,7 @@ typedef struct {
     struct event *buffy_event;
     uint32_t      offset;              /* Should be 64 bit - check protocol */
     uint32_t      blocklen;
+    void         *urlptr;
 } media_t;
 
 struct _stream {
@@ -77,7 +78,7 @@ int stream_init()
 
     event_add(&listen_event,NULL);
 
-    dprintf(DEBUG,"Listening on port %d for stream connection\n",initparams.stream_port);
+    Dprintf(DEBUG,"Listening on port %d for stream connection\n",initparams.stream_port);
 
     return 0;
 
@@ -112,7 +113,9 @@ static void delete_media(media_t *media)
         event_del(media->buffy_event);
         media->buffy_event = NULL;
     }
-    urlhandler_close(media->filename,media->fd);  
+    urlhandler_close(media->filename,media->urlptr,media->fd);  
+    media->urlptr = NULL;
+    media->fd = -1;
 }
 
 void delete_stream(stream_t *stream)
@@ -144,7 +147,7 @@ static void stream_accept(int fd, short event, void *arg)
     if ( ( cfd = tcp_accept(fd,&hostname) ) == -1 ) {
         return;
     }
-    dprintf(DEBUG,"Accepted stream connection from %s\n",hostname);
+    Dprintf(DEBUG,"Accepted stream connection from %s\n",hostname);
     dongle = dongle_return(hostname);
 
     if ( dongle->stream ) {
@@ -209,7 +212,7 @@ static void stream_read(int fd, short event, void *arg)
             diff = media_8(stream,stream->inbuf,stream->inbufstart);
             break;
         default:
-            dprintf(INFO,"Unknown Stream Message\n");
+            Dprintf(INFO,"Unknown Stream Message\n");
             dump_hex(INFO,buf,r);
             diff = stream->inbufstart;
 
@@ -250,7 +253,7 @@ static int media_request(stream_t *stream, unsigned char *buf, int len)
 
     strcpy(media->filename,ptr);    /* Filename is NUL terminated */
 
-    dprintf(DEBUG,"Client has requested %s\n",media->filename);
+    Dprintf(DEBUG,"Client has requested %s\n",media->filename);
 
     /* Now set up the reply string */
     /* Do a random stream id */
@@ -267,32 +270,41 @@ static int media_request(stream_t *stream, unsigned char *buf, int len)
     stream->mediatype = 0;
 
     /* Open the filename now - need to handle no file existing.. */
-    media->fd = urlhandler_open(media->filename,&stream->mediatype);
+    media->fd = urlhandler_open(media->filename,&media->urlptr,&stream->mediatype);
  
+    /* If we write back exactly what we've got then the MVP will abort trying to read
+       the stream, neat! Suspect the trick is buf[4] being 0x00
+    */
+    if ( media->fd != -1 ) {
+        if ( (stream->mediatype & MEDIA_MASK) == MEDIA_MPEG ) {
+            ring_init(&media->buffy, initparams.mpeg_bufsize * 4);
+            buf[4] = 0x01;
+            buf[6] = 0xFF;
 
-    if ( (stream->mediatype & MEDIA_MASK) == MEDIA_MPEG ) {
-        ring_init(&media->buffy, initparams.mpeg_bufsize * 4);
-        buf[4] = 0x01;
-        buf[6] = 0xFF;
+            /* These parameters don't actually seem to matter... */
+            buf[8] =  0x0;    /* FIXME: 720 */
+            buf[9] =  0x0; 
+            buf[10] = 0x0;    /* FIXME: 576 */
+            buf[11] = 0x0;
+            buf[14] = 0x0; // 0x19;    /* 6500 - like it matters... */
+            buf[15] = 0x0; // 0x64;
+        } else {
+            ring_init(&media->buffy, initparams.mp3_bufsize * 4);
+            buf[4] = 0x02;
+        }
 
-        /* These parameters don't actually seem to matter... */
-        buf[8] =  0x02;    /* FIXME: 720 */
-        buf[9] =  0xc0; 
-        buf[10] = 0x02;    /* FIXME: 576 */
-        buf[11] = 0x40;
-        buf[14] = 0x09; // 0x19;    /* 6500 - like it matters... */
-        buf[15] = 0xf0; // 0x64;
-    } else {
-        ring_init(&media->buffy, initparams.mp3_bufsize * 4);
-        buf[4] = 0x02;
-    }
    
-    /* Set up a read event for streaming media */
-    if ( stream->mediatype & MEDIA_SOCKET ) {        
-        media->buffy_event = malloc(sizeof(*media->buffy_event));
-        event_set(media->buffy_event,media->fd,EV_READ,buffer_read,stream);
-        event_add(media->buffy_event,NULL);
-    } 
+        /* Set up a read event for streaming media */
+        if ( stream->mediatype & MEDIA_SOCKET ) {        
+            media->buffy_event = malloc(sizeof(*media->buffy_event));
+            event_set(media->buffy_event,media->fd,EV_READ,buffer_read,stream);
+            event_add(media->buffy_event,NULL);
+        } 
+    } else {
+        printf("No media file found...ack!\n");
+        stream->mediatype = 0;
+        media->urlptr = NULL;
+    }
    
     write(stream->fd,buf,24);
 
@@ -307,7 +319,7 @@ static int media_stop(stream_t *stream, unsigned char *buf, int len)
     if ( len < 24 ) {
         return 0;
     }
-    dprintf(DEBUG,"Stop\n");
+    Dprintf(DEBUG,"Stop\n");
 
     if ( stream->mediatype ) {
         delete_media(media);
@@ -382,11 +394,11 @@ static int media_seek(stream_t *stream, unsigned char *buf, int len)
     if ( len < 24 ) {
         return 0;
     }
-    dprintf(INFO,"Seek received\n");
+    Dprintf(INFO,"Seek received\n");
     dump_hex(INFO,buf,24);
 
 #if 0
-    if ( (stream->mediatype & MEDIA_SOCKET ) == 0 ) {
+    if ( (stream->mediatype & MEDIA_LIVE ) == 0 ) {
         ptr = buf + 8;
         BUF_TO_INT32(offset,ptr);
         
@@ -411,7 +423,7 @@ static int media_8(stream_t *stream, unsigned char *buf, int len)
     if ( len < 24 ) {
         return 0;
     }
-    dprintf(INFO,"Media 8\n");
+    Dprintf(INFO,"Media 8\n");
     dump_hex(INFO,buf,24);
     write(stream->fd,buf,24);
 
@@ -429,7 +441,7 @@ static int media_step(stream_t *stream, unsigned char *buf, int len)
         return 0;
     } 
 
-    dprintf(INFO,"Step received\n");
+    Dprintf(INFO,"Step received\n");
     dump_hex(INFO,buf,24);
 
     ptr = buf + 16;
@@ -470,10 +482,8 @@ static void buffer_read(int fd, short event, void *arg)
 
     /* Check for socket shutdown */
     if ( r == 0 || r == -1 ) {
-        urlhandler_close(media->filename,fd);        
-        media->fd = -1;
-        free(media->buffy_event);
-        media->buffy_event = NULL;
+        delete_media(media);       
+        stream->mediatype = 0;
         return;
     }
 
