@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: url.c,v 1.3 2003/12/04 12:12:40 dom Exp $
- *   $Date: 2003/12/04 12:12:40 $
+ *   $Id: url.c,v 1.8 2003/12/19 21:42:29 dom Exp $
+ *   $Date: 2003/12/19 21:42:29 $
  *
  *
  *   Deals with handling URLs and passing the buck around the place, not
@@ -16,21 +16,21 @@
 
 typedef struct {
     char    *prefix;
-    int      (*open)(char *name, int *type);
-    int      (*close)(char *name, int fd);
-    off_t    (*seek)(char *name, int fd, off_t offset, int whence);
+    int      (*open)(char *name, void **generic_ptr, int *type);
+    int      (*close)(char *name,void *generic_ptr, int fd);
+    off_t    (*seek)(char *name,void  *generic_ptr, int fd, off_t offset, int whence);
 } url_t;
 
 
 static url_t          *url_list = NULL;
 static int             url_num  = 0;
 
-static int             http_open(char *name, int *type);
-static int             http_close(char *name, int fd);
+static int             http_open(char *name, void **ptr, int *type);
+static int             http_close(char *name,void *ptr, int fd);
 
-static int             file_open(char *name, int *type);
-static off_t           file_seek(char *name, int fd, off_t offset, int whence);
-static int             file_close(char *name, int fd);
+static int             file_open(char *name, void **ptr, int *type);
+static off_t           file_seek(char *name,void *ptr, int fd, off_t offset, int whence);
+static int             file_close(char *name,void *ptr, int fd);
 
 
 int urlhandler_init()
@@ -38,6 +38,7 @@ int urlhandler_init()
     /* Add some inbuilt directors */
     urlhandler_add("mpeg;http://",http_open,http_close,NULL);
     urlhandler_add("mp3;http://",http_open,http_close,NULL);
+    urlhandler_add("http://",http_open,http_close,NULL);
     urlhandler_add("file://",file_open,file_close,file_seek);
 
     return 0;
@@ -59,9 +60,9 @@ static url_t *urlhandler_find(char *name)
 
 
 void urlhandler_add(char *prefix,
-                    int      (*open)(char *name, int *type),
-                    int      (*close)(char *name, int fd),
-                    off_t    (*seek)(char *name, int fd, off_t offset, int whence))
+                    int      (*open)(char *name, void **ptr, int *type),
+                    int      (*close)(char *name,void *ptr, int fd),
+                    off_t    (*seek)(char *name,void *ptr, int fd, off_t offset, int whence))
 {
     url_t   *url = urlhandler_find(prefix);
     int      i;
@@ -80,34 +81,34 @@ void urlhandler_add(char *prefix,
     url->seek  = seek;
 }
 
-int urlhandler_open(char *name, int *type)
+int urlhandler_open(char *name, void **generic_ptr, int *type)
 {
     url_t  *url = urlhandler_find(name);
 
     if ( url && url->open ) {
-        return url->open(name,type);       
+        return url->open(name,generic_ptr,type);       
     }
     return -1;
 }
 
-off_t urlhandler_seek(char *name, int fd, off_t offset, int whence)
+off_t urlhandler_seek(char *name, void *ptr, int fd, off_t offset, int whence)
 {
     url_t   *url = urlhandler_find(name);
 
     if ( url && url->seek ) {
-        return url->seek(name,fd,offset,whence);
+        return url->seek(name,ptr,fd,offset,whence);
     }
 
     return (off_t) -1;
 }
 
 
-int urlhandler_close(char *name, int fd)
+int urlhandler_close(char *name, void *ptr, int fd)
 {
     url_t   *url = urlhandler_find(name);
 
     if ( url && url->close ) {
-        return url->close(name,fd);
+        return url->close(name,ptr,fd);
     }
 
     return -1;
@@ -192,7 +193,7 @@ static char *url2host (uint8_t *url, char **name, uint32_t *ip, uint32_t *port)
 }
 
 #define ACCEPT "Accept: video/mpeg, video/x-mpegurl, */*\r\n"
-static int http_open(char *url, int *type)
+static int http_open(char *url, void **genptr,int *type)
 {
     char purl[1024], *host, req[1024], *sptr;
     uint32_t ip;
@@ -202,15 +203,30 @@ static int http_open(char *url, int *type)
     struct sockaddr_in server;
     int mfd;
 
+    *genptr = NULL;
+
     /* This is a bit of splendiferous hack <grin> */
     if ( strncmp(url,"mpeg;",5) == 0 ) {
-        *type = MEDIA_MPEG | MEDIA_SOCKET;
+        *type = MEDIA_MPEG | MEDIA_SOCKET | MEDIA_LIVE;
         url += 5;
     } else if ( strncmp(url,"mp3;",3) == 0 ) {
-        *type = MEDIA_MP3 | MEDIA_SOCKET;
+        *type = MEDIA_MP3 | MEDIA_SOCKET | MEDIA_LIVE;
         url += 4;
-    } else {       /* Unknown type */
-        return -1;
+    } else {       /* Unknown type, try to guess from the file extension */
+        char    *ptr;
+
+        if ( (ptr = strrchr(url,'.') ) == NULL ) {
+            /* No extension, we're not smart so return no such file */
+            return -1;
+        }
+        if ( strcasecmp(ptr,".mp3") == 0 ) {
+            *type = MEDIA_MP3;
+        } else if ( strcasecmp(ptr,".mpeg") == 0 || strcasecmp(ptr,".vdr") == 0 ||
+                    strcasecmp(ptr,".mpg") == 0 ) {
+            *type = MEDIA_MPEG;
+        } else {
+            return -1;
+        }        
     }
 
     strncpy (purl, url, 1023);
@@ -220,7 +236,7 @@ static int http_open(char *url, int *type)
         host = NULL;
         strcpy (req, "GET ");
         if (!(sptr = url2host(purl, &host, &ip, &port))) {
-            dprintf(ERROR,"Unknown host %s\n",purl);
+            Dprintf(ERROR,"Unknown host %s\n",purl);
             return -1;
         }
         strcat (req, sptr);
@@ -268,7 +284,7 @@ static int http_open(char *url, int *type)
             case '3':
                 reloc = 1;
             default:
-                dprintf(ERROR, "HTTP req failed:%s",sptr+1);
+                Dprintf(ERROR, "HTTP req failed:%s",sptr+1);
                 close(mfd);
                 shutdown(mfd,SHUT_RDWR);
                 return -1;             
@@ -283,7 +299,7 @@ static int http_open(char *url, int *type)
         } while (req[0] != '\r' && req[0] != '\n');
     } while (reloc && purl[0] && relocnum++ < 3);
     if (reloc) {
-        dprintf(ERROR,"Too many HTTP relocations.\n");
+        Dprintf(ERROR,"Too many HTTP relocations.\n");
         close(mfd);
         shutdown(mfd,SHUT_RDWR);
         return -1;
@@ -292,7 +308,7 @@ static int http_open(char *url, int *type)
     return sock;
 }
 
-static int http_close(char *filename, int fd)
+static int http_close(char *name,void *ptr, int fd)
 {
     close(fd);
     shutdown(fd,SHUT_RDWR);
@@ -301,23 +317,25 @@ static int http_close(char *filename, int fd)
 
 
                 
-static int file_close(char *name, int fd)
+static int file_close(char *name,void *ptr, int fd)
 {
     close(fd);
     return 0;
 }
 
-static off_t file_seek(char *name, int fd, off_t off, int whence)
+static off_t file_seek(char *name, void *ptr, int fd, off_t off, int whence)
 {
     return lseek(fd,off,whence);
 }
 
-static int file_open(char *name, int *type)
+static int file_open(char *name, void **genptr, int *type)
 {
     char   *ptr;
     char   *filename;
     int     fd;
 
+    *genptr = NULL;
+
     /* This shouldn't happen... */
     if ( strncmp(name,"file://",7) ) {
         return -1;
@@ -335,7 +353,7 @@ static int file_open(char *name, int *type)
     if ( strcasecmp(ptr,".mp3") == 0 ) {
         *type = MEDIA_MP3;
     } else if ( strcasecmp(ptr,".mpeg") == 0 || strcasecmp(ptr,".vdr") == 0 ||
-                strcasecmp(ptr,".mpg") == 0 ) {
+                strcasecmp(ptr,".mpg") == 0 || strcasecmp(ptr,".nvu") == 0 ) {
         *type = MEDIA_MPEG;
     } else {
         return -1;
